.. More Sage Thematic Tutorials documentation master file, created by
   sphinx-quickstart on Fri Apr 28 17:20:28 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Utilities for authoring SageMath packages
=========================================

.. toctree::
   :maxdepth: 3

   sage_package/setuptools
   sage_package/sphinx
   sage_package/sphinx-demo

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
